@@ -15,7 +15,6 @@ import subprocess
 import sys
 import textwrap
 import zipfile
-from distutils.spawn import find_executable
 from pathlib import Path
 from pipes import quote
 from sys import platform
@@ -437,9 +436,10 @@ class Shell(object):
             return
         try:
             shutil.rmtree(path_expand(top))
-        except OSError as e:
-            print(e.strerror)
-            assert False, "Directory {location} could not be deleted"
+        except Exception as e:
+            pass
+            # print(e.strerror)
+            # assert False, f"Directory {top} could not be deleted"
 
     @staticmethod
     def dot2svg(filename, engine='dot'):
@@ -1081,7 +1081,7 @@ class Shell(object):
         :param command: teh command
         :return: the path
         """
-        return find_executable(command)
+        return shutil.which(command)
 
     @classmethod
     def command_exists(cls, name):
