@@ -90,6 +90,17 @@ class Console(object):
 
     theme = theme_color
 
+    def line(self, c="="):
+        try:
+            size = os.get_terminal_size()
+            columns = size.columns
+        except:
+            columns = 79
+
+        # lines = size.lines
+
+        print(columns * c)
+
     # noinspection PyPep8Naming
     def red(msg):
         print(Fore.RED + msg + Style.RESET_ALL)
@@ -340,6 +351,7 @@ if __name__ == "__main__":
 
     print(Console.theme)
 
+    Console.line()
     Console.warning("Warning")
     Console.error("Error")
     Console.info("Info")
@@ -355,3 +367,4 @@ if __name__ == "__main__":
     print(Style.DIM + 'and in dim text')
     print(Fore.RESET + Back.RESET + Style.RESET_ALL)
     print('back to normal now')
+    Console.line()
